@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Author: Don Welch
+# Author: Don Welch, Naga Samrat Chowdary Narla,
 #
 
 __version__ = '5.0'
@@ -39,7 +39,7 @@ from prnt import cups
 
 
 def enterAlignmentNumber(letter, hortvert, colors, line_count, maximum):
-    ok, value = tui.enter_range("Enter the best aligned value for line %s (1-%d): " %
+    ok, value = tui.enter_range("From the printed Alignment page, Enter the best aligned value for line %s (1-%d): " %
                         (letter, maximum),
                         1,
                         maximum)
@@ -167,7 +167,7 @@ try:
                 d.close()
 
                 if align_type == ALIGN_TYPE_UNSUPPORTED:
-                    log.error("Alignment through HPLIP not supported for this printer. Please use the printer's front panel to perform cartrdige alignment.")
+                    log.error("Alignment through HPLIP not supported for this printer. Please use the printer's front panel to perform cartridge alignment.")
 
                 elif align_type == ALIGN_TYPE_AUTO:
                     maint.AlignType1PML(d, tui.load_paper_prompt)
@@ -206,6 +206,15 @@ try:
                 elif align_type == ALIGN_TYPE_LIDIL_DJ_D1600:
                     maint.AlignType14(d, tui.load_paper_prompt, type10and11and14Align, invalidPen2)
 
+                elif align_type == ALIGN_TYPE_LEDM:
+                    maint.AlignType15(d, tui.load_paper_prompt, aioUI2)
+
+                elif align_type == ALIGN_TYPE_LEDM_MANUAL:
+                    maint.AlignType16(d, tui.load_paper_prompt, enterAlignmentNumber)
+
+                elif align_type == ALIGN_TYPE_LEDM_FF_CC_0:
+                    maint.AlignType17(d, tui.load_paper_prompt, aioUI2)
+
                 else:
                     log.error("Invalid alignment type.")
 
