@@ -1,3 +1,4 @@
+#!/bin/env python
 # -*- coding: utf-8 -*-
 #
 # (c) Copyright 2003-2009 Hewlett-Packard Development Company, L.P.
@@ -43,9 +44,13 @@ import status
 import pml
 import status
 from prnt import pcl, ldl, cups
-import models, mdns, slp
+from base import models, mdns, slp, avahi
 from strings import StringTable
 
+http_result_pat = re.compile("""HTTP/\d.\d\s(\d+)""", re.I)
+
+HTTP_OK = 200
+HTTP_ERROR = 500
 
 try:
     import hpmudext
@@ -82,7 +87,7 @@ DEFAULT_FILTER = None
 VALID_FILTERS = ('print', 'scan', 'fax', 'pcard', 'copy')
 DEFAULT_BE_FILTER = ('hp',)
 
-pat_deviceuri = re.compile(r"""(.*):/(.*?)/(\S*?)\?(?:serial=(\S*)|device=(\S*)|ip=(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}[^&]*)|zc=(\S+))(?:&port=(\d))?""", re.IGNORECASE)
+pat_deviceuri = re.compile(r"""(.*):/(.*?)/(\S*?)\?(?:serial=(\S*)|device=(\S*)|ip=(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}[^&]*)|zc=(\S+)|hostname=(\S+))(?:&port=(\d))?""", re.IGNORECASE)
 http_pat_url = re.compile(r"""/(.*?)/(\S*?)\?(?:serial=(\S*)|device=(\S*))&loc=(\S*)""", re.IGNORECASE)
 direct_pat = re.compile(r'direct (.*?) "(.*?)" "(.*?)" "(.*?)"', re.IGNORECASE)
 
@@ -250,9 +255,9 @@ def init_dbus(dbus_loop=None):
                 session_bus = dbus.SessionBus(dbus_loop)
         except dbus.exceptions.DBusException, e:
             if os.getuid() != 0:
-                log.error("Unable to connect to dbus session bus.")
+                log.error("Unable to connect to dbus session bus. %s "%e)
             else:
-                log.debug("Unable to connect to dbus session bus (running as root?)")
+                log.debug("Unable to connect to dbus session bus (running as root?). %s "%e)
 
             dbus_avail = False
             return dbus_avail, None,  None
@@ -363,8 +368,19 @@ def makeURI(param, port=1):
             log.debug("Found: %s" % uri)
             found = True
             cups_uri = uri
-        else:
-            log.debug("Not found.")
+
+        else: # Try DNS hostname
+            log.debug("Device not found using mDNS hostname. Trying with DNS hostname %s" % param)
+
+            result_code, uri = hpmudext.make_net_uri(param, port)
+
+            if result_code == hpmudext.HPMUD_R_OK and uri:
+                uri = uri.replace("ip","hostname")
+                log.debug("Found: %s" % uri)
+                found = True
+                cups_uri = uri
+            else:
+                log.debug("Not found.")
 
     if not found:
         log.debug("Trying serial number %s" % param)
@@ -450,7 +466,7 @@ def queryModelByURI(device_uri):
 #
 
 def probeDevices(bus=DEFAULT_PROBE_BUS, timeout=10,
-                 ttl=4, filter=DEFAULT_FILTER,  search='', net_search='mdns',
+                 ttl=4, filter=DEFAULT_FILTER,  search='', net_search='slp',
                  back_end_filter=('hp',)):
 
     num_devices, ret_devices = 0, {}
@@ -475,7 +491,13 @@ def probeDevices(bus=DEFAULT_PROBE_BUS, timeout=10,
                 except Error, socket.error:
                     log.error("An error occured during network probe.")
                     raise ERROR_INTERNAL
-            else:
+            elif net_search == 'avahi':
+                try:
+                    detected_devices = avahi.detectNetworkDevices(ttl, timeout)
+                except Error, socket.error:
+                    log.error("An error occured during network probe.")
+                    raise ERROR_INTERNAL
+            else :#if net_search = 'mdns'
                 try:
                     detected_devices = mdns.detectNetworkDevices(ttl, timeout)
                 except Error, socket.error:
@@ -814,9 +836,14 @@ def parseDeviceURI(device_uri):
     serial = m.group(4) or ''
     dev_file = m.group(5) or ''
     host = m.group(6) or ''
-    zc = ''
-    if not host:
-        zc = host = m.group(7) or ''
+    zc = m.group(7) or ''
+    hostname = m.group(8) or ''
+
+    if hostname:
+        host = hostname
+    elif zc:
+        host = zc
+
     port = m.group(8) or 1
 
     if bus == 'net':
@@ -972,10 +999,16 @@ AGENT_types = { AGENT_TYPE_NONE        : 'invalid',
                 #AGENT_TYPE_C_K         : 'cyan_and_black',
                 AGENT_TYPE_LG_PK       : 'light_gray_and_photo_black',
                 AGENT_TYPE_LG          : 'light_gray',
-                AGENT_TYPE_G           : 'medium_gray',
+                AGENT_TYPE_G           : 'gray',
+                AGENT_TYPE_DG          : 'dark_gray',
                 AGENT_TYPE_PG          : 'photo_gray',
                 AGENT_TYPE_C_M         : 'cyan_and_magenta',
                 AGENT_TYPE_K_Y         : 'black_and_yellow',
+                AGENT_TYPE_PHOTO_BLACK : 'photo_black',
+                AGENT_TYPE_LC          : 'light_cyan',
+                AGENT_TYPE_LM          : 'light_magenta',
+                AGENT_TYPE_MATTE_BLACK : 'matte_black',
+                AGENT_TYPE_RED         : 'red',
                 AGENT_TYPE_UNSPECIFIED : 'unspecified', # Kind=5,6
             }
 
@@ -1082,6 +1115,11 @@ class Device(object):
 
         log.debug("Model/UI model: %s/%s" % (self.model, self.model_ui))
 
+        if self.bus == 'net':
+            self.http_host = self.host
+        else:
+            self.http_host = 'localhost'  
+
         # TODO:
         #service.setAlertsEx(self.hpssd_sock)
 
@@ -1390,6 +1428,9 @@ class Device(object):
 
     def getDeviceID(self):
         needs_close = False
+        self.raw_deviceID = ''
+        self.deviceID = {}
+
         if self.io_state != IO_STATE_HP_OPEN:
            try:
                self.open()
@@ -1399,10 +1440,7 @@ class Device(object):
 
         result_code, data = hpmudext.get_device_id(self.device_id)
 
-        if result_code != hpmudext.HPMUD_R_OK:
-            self.raw_deviceID = ''
-            self.deviceID = {}
-        else:
+        if result_code == hpmudext.HPMUD_R_OK:
             self.raw_deviceID = data
             self.deviceID = parseDeviceID(data)
 
@@ -2166,6 +2204,41 @@ class Device(object):
     def readWifiConfig(self, bytes_to_read, stream=None, timeout=prop.read_timeout, allow_short_read=True):
         return self.__readChannel(self.openWifiConfig, bytes_to_read, stream, timeout, allow_short_read)
 
+#Common handling of reading chunked or unchunked data from LEDM devices
+    def readLEDMData(dev, func, reply, timeout=6):
+
+        END_OF_DATA="0\r\n\r\n"
+        bytes_requested = 1024
+        bytes_remaining = 0
+        chunkedFlag = True
+
+        bytes_read = func(bytes_requested, reply, timeout)
+
+        for line in reply.getvalue().splitlines():
+            if line.lower().find("content-length") != -1:
+                 bytes_remaining = int(line.split(":")[1])
+                 chunkedFlag = False
+                 break
+
+        xml_data_start = reply.getvalue().find("<?xml")
+        if (xml_data_start != -1):
+            bytes_remaining = bytes_remaining - (len(reply.getvalue())  - xml_data_start)
+
+        while bytes_read > 0:
+            temp_buf = xStringIO()
+            bytes_read = func(bytes_requested, temp_buf, timeout)
+
+            reply.write(temp_buf.getvalue())
+
+            if not chunkedFlag:     # Unchunked data
+                bytes_remaining = bytes_remaining - bytes_read
+                if bytes_remaining <= 0:
+                    break
+            elif END_OF_DATA == temp_buf.getvalue():   # Chunked data end
+                    break
+
+
+
     def __readChannel(self, opener, bytes_to_read, stream=None,
                       timeout=prop.read_timeout, allow_short_read=False):
 
@@ -2302,6 +2375,52 @@ class Device(object):
 
         self.printData(data, direct=direct, raw=True)
 
+    def post(self, url, post):
+        status_type = self.mq.get('status-type', STATUS_TYPE_NONE)
+        data = """POST %s HTTP/1.1\r
+Connection: Keep-alive\r
+User-agent: hplip/2.0\r
+Host: %s\r
+Content-type: text/xml\r
+Content-length: %d\r
+\r
+%s""" % (url, self.http_host, len(post), post)
+        log.log_data(data)
+        if status_type == STATUS_TYPE_LEDM:
+            log.debug("status-type: %d" % status_type)
+            self.writeEWS_LEDM(data)
+            response = cStringIO.StringIO()
+            func = self.readEWS_LEDM
+
+            self.readLEDMData(func, response)
+
+            response = response.getvalue()
+            log.log_data(response)
+            self.closeEWS_LEDM()
+
+        elif status_type == STATUS_TYPE_LEDM_FF_CC_0:
+            log.debug("status-type: %d" % status_type)
+            self.writeLEDM(data)
+            response = cStringIO.StringIO()
+            func = self.readLEDM
+
+            self.readLEDMData(func, response)
+
+            response = response.getvalue()
+            log.log_data(response)
+            self.closeLEDM()
+
+        else:
+            log.error("Not an LEDM status-type: %d" % status_type)
+
+        match = http_result_pat.match(response)
+        if match is None: return HTTP_OK
+        try:
+            code = int(match.group(1))
+        except (ValueError, TypeError):
+            code = HTTP_ERROR
+
+        return code == HTTP_OK
 
     def printGzipFile(self, file_name, printer_name=None, direct=False, raw=True, remove=False):
         return self.printFile(file_name, printer_name, direct, raw, remove)
@@ -2671,39 +2790,12 @@ class LocalOpenerEWS_LEDM(urllib.URLopener):
             dev.writeEWS_LEDM("""GET %s HTTP/1.1\r\nAccept: text/plain\r\nHost:localhost\r\nUser-Agent:hplip\r\n\r\n""" % loc)
 
         reply = xStringIO()
+        func = dev.readEWS_LEDM
 
         #while dev.readEWS_LEDM(512, reply, timeout=3):
             #pass
 
-        END_OF_DATA="0\r\n\r\n"
-        bytes_requested = 1024
-        bytes_remaining = 0
-        chunkedFlag = True
-
-        bytes_read = dev.readEWS_LEDM(bytes_requested, reply, timeout=3)
-
-        for line in reply.getvalue().splitlines():
-            if line.lower().find("content-length") != -1:
-                 bytes_remaining = int(line.split(":")[1])
-                 chunkedFlag = False
-                 break
-
-        xml_data_start = reply.getvalue().find("<?xml")
-        if (xml_data_start != -1):
-            bytes_remaining = bytes_remaining - (len(reply.getvalue())  - xml_data_start)
-
-
-        while bytes_read > 0:
-            temp_buf = xStringIO()
-            bytes_read = dev.readEWS_LEDM(bytes_requested, temp_buf, timeout=3)
-            reply.write(temp_buf.getvalue())
-
-            if not chunkedFlag:     # Unchunked data
-                bytes_remaining = bytes_remaining - bytes_read
-                if bytes_remaining <= 0:
-                    break
-            elif END_OF_DATA == temp_buf.getvalue():   # Chunked data end
-                    break
+        dev.readLEDMData(func, reply)
 
         reply.seek(0)
         return reply.getvalue()
@@ -2728,38 +2820,11 @@ class LocalOpener_LEDM(urllib.URLopener):
             dev.writeLEDM("""GET %s HTTP/1.1\r\nAccept: text/plain\r\nHost:localhost\r\nUser-Agent:hplip\r\n\r\n""" % loc)
 
         reply = xStringIO()
+        func = dev.readLEDM
 
         #while dev.readLEDM(512, reply, timeout=3):
             #pass
-
-        END_OF_DATA="0\r\n\r\n"
-        bytes_requested = 1024
-        bytes_remaining = 0
-        chunkedFlag = True
-
-        bytes_read = dev.readLEDM(bytes_requested, reply, timeout=3)
-
-        for line in reply.getvalue().splitlines():
-            if line.lower().find("content-length") != -1:
-                 bytes_remaining = int(line.split(":")[1])
-                 chunkedFlag = False
-                 break
-
-        xml_data_start = reply.getvalue().find("<?xml")
-        if (xml_data_start != -1):
-            bytes_remaining = bytes_remaining - (len(reply.getvalue())  - xml_data_start)
-
-        while bytes_read > 0:
-            temp_buf = xStringIO()
-            bytes_read = dev.readLEDM(bytes_requested, temp_buf, timeout=3)
-            reply.write(temp_buf.getvalue())
-
-            if not chunkedFlag:     # Unchunked data
-                bytes_remaining = bytes_remaining - bytes_read
-                if bytes_remaining <= 0:
-                    break
-            elif END_OF_DATA == temp_buf.getvalue():   # Chunked data end
-                    break
+        dev.readLEDMData(func, reply)
 
         reply.seek(0)
         return reply.getvalue()
