@@ -8,7 +8,7 @@
 # All Rights Reserved
 #
 # Modifications by Don Welch
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2008 Hewlett-Packard Development Company, L.P.
 #
 # Redistribution and use in source and binary forms, with or without modification,
 # are permitted provided that the following conditions are met:
@@ -1236,6 +1236,10 @@ def whatis(data):
         if ord(c) == 0:
             return 'data'
 
+    # its ASCII, now do C/CPP tests
+    if data.find('#include', 0, 256) > -1 or data.find('/***', 0, 256) > -1:
+        return 'text/cpp'
+
     # its ASCII, now do text tests
     if data.find('!/usr/bin/env python', 0, 256) > -1 or data.find('def ', 0, 8192) > -1:
         return 'application/x-python'
