@@ -180,12 +180,13 @@ class StringTable:
             '5026' : (self.__tr("Device status not available"), ''),
             '5031' : ('%5021%', ''),
             '5034' : (self.__tr('Device does not support requested operation'), '%try_again%'),
-            '5501' : (self.__tr('Device added'), ''),
             '6000' : (self.__tr('Photocard unload started'), ''),
             '6001' : (self.__tr('Photocard unload ended'), ''),
             '6002' : (self.__tr('Photocard unload failed'), self.__tr('Make sure photocard is inserted properly and try again')),
             '6003' : (self.__tr('Unable to mount photocard on device'), '%6002%'),
             '6004' : (self.__tr('Photocard unloaded successfully'), ''),
+            '9000' : (self.__tr('Device Added'), ''),
+            '9041' : (self.__tr('Device Removed'), ''),
             'unknown_error' : (self.__tr('Unknown error'), ''),
             'print' : (self.__tr('Print'), ''),
             'scan' : (self.__tr('Scan'), ''),
@@ -210,21 +211,33 @@ class StringTable:
             'agent_cyan_head' : (self.__tr('Cyan print head'), ''),
             'agent_cyan_supply' : (self.__tr('Cyan ink cartridge'), ''),
             'agent_cyan_cartridge' : (self.__tr('Cyan cartridge'), ''),
+            'agent_light_cyan_head' : (self.__tr('Light Cyan print head'), ''),
+            'agent_light_cyan_supply' : (self.__tr('Light Cyan ink cartridge'), ''),
+            'agent_light_cyan_cartridge' : (self.__tr('Light Cyan cartridge'), ''),
             'agent_magenta_head' : (self.__tr('Magenta print head'), ''),
             'agent_magenta_supply' : (self.__tr('Magenta ink cartridge'), ''),
             'agent_magenta_cartridge':(self.__tr('Magenta cartridge'), ''),
             'agent_yellow_head' : (self.__tr('Yellow print head'), ''),
             'agent_yellow_supply' : (self.__tr('Yellow ink cartridge'), ''),
             'agent_yellow_cartridge': (self.__tr('Yellow cartridge'), ''),
+            'agent_red_head' : (self.__tr('Red print head'), ''),
+            'agent_red_supply' : (self.__tr('Red ink cartridge'), ''),
+            'agent_red_cartridge': (self.__tr('Red cartridge'), ''),
             'agent_photo_black_head' : (self.__tr('Photo Black print head'), ''),
             'agent_photo_black_supply' : (self.__tr('Photo Black ink cartridge'), ''),
             'agent_photo_black_cartridge': (self.__tr('Photo Black cartridge'), ''),
             'agent_matte_black_head' : (self.__tr('Matte Black print head'), ''),
             'agent_matte_black_supply' : (self.__tr('Matte Black ink cartridge'), ''),
             'agent_matte_black_cartridge': (self.__tr('Matte Black cartridge'), ''),
-            'agent_light_gray_head' : (self.__tr('Gray print head'), ''),
-            'agent_light_gray_supply' : (self.__tr('Gray ink cartridge'), ''),
-            'agent_light_gray_cartridge': (self.__tr('Gray cartridge'), ''),
+            'agent_gray_head' : (self.__tr('Gray print head'), ''),
+            'agent_gray_supply' : (self.__tr('Gray ink cartridge'), ''),
+            'agent_gray_cartridge': (self.__tr('Gray cartridge'), ''),
+            'agent_light_gray_head' : (self.__tr('Light Gray print head'), ''),
+            'agent_light_gray_supply' : (self.__tr('Light Gray ink cartridge'), ''),
+            'agent_light_gray_cartridge': (self.__tr('Light Gray cartridge'), ''),
+            'agent_dark_gray_head' : (self.__tr('Dark Gray print head'), ''),
+            'agent_dark_gray_supply' : (self.__tr('Dark Gray ink cartridge'), ''),
+            'agent_dark_gray_cartridge': (self.__tr('Dark Gray cartridge'), ''),
             'agent_photo_cyan_head' : (self.__tr('Photo cyan print head'), ''),
             'agent_photo_cyan_supply' : (self.__tr('Photo cyan ink cartridge'), ''),
             'agent_photo_cyan_cartridge' : (self.__tr('Photo cyan cartridge'), ''),
