@@ -23,7 +23,7 @@
 __version__ = '1.0'
 __title__ = 'Self Diagnse Utility and Healing Utility'
 __mod__ = 'hp-doctor'
-__doc__ = """Check for the deprecated, plug-in, dependencies, queues and Permission issues. And provides self diagnose steps"""
+__doc__ = """Tool checks for the deprecated, plug-in, dependencies, queues, permission issues and provides self diagnose steps"""
 
 
 # global import
@@ -125,7 +125,7 @@ def install_plugin(core):
         log.info("Plugin's already installed")
         return True
     else:
-        log.info("HP Properitery Plugin's are not required as no plug-in printer is present.")
+        log.info("No plug-in printers are configured.")
         return True
 
     if ok and user_input == 'y':
@@ -149,8 +149,7 @@ def deprecated_check(core):
         log.info("No Deprecated items are found")
     else:
         log.error("This distro (i.e %s  %s) is either deprecated or not yet supported."%(core.distro_name, core.distro_version))
-        ok,user_input =tui.enter_choice(log.red("The diagnosis is limited on unsupported platforms. Do you want to continue?(y=yes, n=no*):"),['y', 'n'], 'n')
-#        ok,user_input =tui.enter_choice(log.red("This tool may not diagnose all the problems. Do you want to continue?(y=yes, n=no*)"),['y', 'n'], 'n')
+        ok,user_input =tui.enter_choice(log.red("The diagnosis is limited on unsupported platforms. Do you want to continue?(y=yes*, n=no):"),['y', 'n'], 'y')
         if not ok or user_input !='y':
             clean_exit(2)
 
@@ -247,7 +246,7 @@ try:
     mod.lockInstance('')
     mod.quiet= False
     mod.showTitle()
-    log_file = os.path.normpath('/var/log/hp/hp-doctor.log')
+    log_file = os.path.normpath('%s/hp-doctor.log'%prop.user_dir)
 
     if os.path.exists(log_file):
         try:
@@ -299,16 +298,17 @@ try:
             core.install_missing_dependencies(INTERACTIVE_MODE,core.get_required_deps(),core.get_optional_deps(), core.get_cmd_to_run())
 
         log.info(log.bold("\n\nChecking Permissions...."))
-        if not core.get_missing_user_grps() and not core.get_disable_selinux_status():
+#        if not core.get_missing_user_grps() and not core.get_disable_selinux_status():
+        if not core.get_disable_selinux_status():
             log.info("Permissions are correct.")
 
-        if core.get_missing_user_grps():
-            log.info(log.bold("Missing User Groups"))
-            log.info(log.bold('-'*len("Missing User Groups")))
-            log.info("%s"%core.get_missing_user_grps())
-            authenticate(core)
-            if core.add_groups_to_user(core.get_missing_user_grps(), core.get_user_grp_cmd()):
-                IS_RESTART_REQ = True
+#        if core.get_missing_user_grps():
+#            log.info(log.bold("Missing User Groups"))
+#            log.info(log.bold('-'*len("Missing User Groups")))
+#            log.info("%s"%core.get_missing_user_grps())
+#            authenticate(core)
+#            if core.add_groups_to_user(core.get_missing_user_grps(), core.get_user_grp_cmd()):
+#                IS_RESTART_REQ = True
 
         if core.get_disable_selinux_status():
             log.info(log.bold("SELinux Status"))
@@ -319,7 +319,7 @@ try:
                 IS_RESTART_REQ = True
 
     log.info(log.bold("\n\nChecking for Configured Queues...."))
-    queues.main_function(core.passwordObj, MODE,ui_toolkit, False,False, DEVICE_URI)
+    queues.main_function(core.passwordObj, MODE,ui_toolkit, False, DEVICE_URI)
 
     log.info(log.bold("\n\nChecking for HP Properitery Plugin's...."))
     ### Check for Plugin Printers
