@@ -1239,6 +1239,8 @@ int __attribute__ ((visibility ("hidden"))) pp_probe_devices(char *lst, int lst_
                hpmud_query_model(dev, &ma); 
                if (ma.support != HPMUD_SUPPORT_TYPE_HPLIP)
                {
+                  release_pp(fd);
+                  close(fd);
                   BUG("ignoring %s support=%d\n", dev, ma.support);
                   continue;           /* ignor, not supported */
                }
