@@ -31,7 +31,7 @@ import glob
 
 # Local
 from base.g import *
-from base import utils, models
+from base import utils, models, os_utils
 
 INVALID_PRINTER_NAME_CHARS = """~`!@#$%^&*()=+[]{}()\\/,.<>?'\";:| """
 
@@ -203,7 +203,7 @@ def getPPDPath(addtional_paths=None):
 
 def getAllowableMIMETypes():
     """
-        Scan all /etc/cups/*.convs and /usr/share/cups/mime 
+        Scan all /etc/cups/*.convs and /usr/share/cups/mime
         files for allowable file formats.
     """
     paths = []
@@ -468,8 +468,8 @@ def getPPDFile2(mq,model, ppds): # New PPD find
     # and beginning with implementation in 2.8.12 (Qt4 hp-setup)
     # hp-<model name from models.dat w/o beginning hp_>[-<pdl>][-<pdl>][...].ppd[.gz]
     # 3.9.6: Added handling for hpijs vs. hpcups PPDs/DRVs
-    
-    
+
+
     #Check if common ppd name is already given in models.dat(This is needed because in case of devices having more than one derivatives
     #will have diffrent model name strings in device ID, because of which we don't get the common ppd name for search)
     model = models.normalizeModelName(model)
@@ -478,7 +478,7 @@ def getPPDFile2(mq,model, ppds): # New PPD find
         stripped_model = stripModel2(model)
     else:
         stripped_model = stripModel2(ppd_name)
-        
+
     log.debug("Matching PPD list to model  %s..." % stripped_model)
 
     matches = []
@@ -501,7 +501,7 @@ def getPPDFile2(mq,model, ppds): # New PPD find
     num_matches = len(matches)
 
     if num_matches == 0:
-        log.warn("No PPD found for model %s using new algorithm. Trying old algorithm..." % stripped_model)
+        log.debug("No PPD found for model %s using new algorithm. Trying old algorithm..." % stripped_model)
         #Using Old algo, ignores the series keyword in ppd searching.
         matches2 = getPPDFile(stripModel(stripped_model), ppds).items()
         log.debug(matches2)
@@ -555,7 +555,7 @@ def getPPDFile2(mq,model, ppds): # New PPD find
 
 ##
 # Function :- getFaxPPDFile()
-# Arguments:- 
+# Arguments:-
 #   1) mq  -->  Device model query object
 #    2) model --> Fax model name
 # Return arguments:-
@@ -689,27 +689,27 @@ def getDefaultPrinter():
     return r
 
 def setDefaultPrinter(printer_name):
-    setPasswordPrompt("You do not have permission to set the default printer.")
+    setPasswordPrompt("You do not have permission to set the default printer. You need authentication.")
     return cupsext.setDefaultPrinter(printer_name)
 
 def accept(printer_name):
-    setPasswordPrompt("You do not have permission to accept jobs on a printer queue.")
+    setPasswordPrompt("You do not have permission to accept jobs on a printer queue. You need authentication.")
     return controlPrinter(printer_name, CUPS_ACCEPT_JOBS)
 
 def reject(printer_name):
-    setPasswordPrompt("You do not have permission to reject jobs on a printer queue.")
+    setPasswordPrompt("You do not have permission to reject jobs on a printer queue. You need authentication.")
     return controlPrinter(printer_name, CUPS_REJECT_JOBS)
 
 def start(printer_name):
-    setPasswordPrompt("You do not have permission to start a printer queue.")
+    setPasswordPrompt("You do not have permission to start a printer queue. You need authentication.")
     return controlPrinter(printer_name, IPP_RESUME_PRINTER)
 
 def stop(printer_name):
-    setPasswordPrompt("You do not have permission to stop a printer queue.")
+    setPasswordPrompt("You do not have permission to stop a printer queue. You need authentication.")
     return controlPrinter(printer_name, IPP_PAUSE_PRINTER)
 
 def purge(printer_name):
-    setPasswordPrompt("You do not have permission to purge jobs.")
+    setPasswordPrompt("You do not have permission to purge jobs. You need authentication.")
     return controlPrinter(printer_name, IPP_PURGE_JOBS)
 
 def controlPrinter(printer_name, cups_op):
@@ -770,7 +770,7 @@ def getServer():
     return cupsext.getServer()
 
 def cancelJob(jobid, dest=None):
-    setPasswordPrompt("You do not have permission to cancel a job.")
+    setPasswordPrompt("You do not have permission to cancel a job. You need authentication.")
     if dest is not None:
         return cupsext.cancelJob(dest, jobid)
     else:
@@ -796,11 +796,12 @@ def printFile(printer, filename, title):
 	filename = filename.encode('utf-8')
 	title = title.encode('utf-8')
         return cupsext.printFileWithOptions(printer, filename, title)
-	
+
     else:
         return -1
 
 def addPrinter(printer_name, device_uri, location, ppd_file, model, info):
+    setPasswordPrompt("You do not have permission to add a printer. You need authentication.")
     log.debug("addPrinter('%s', '%s', '%s', '%s', '%s', '%s')" %
         ( printer_name, device_uri, location, ppd_file, model, info))
 
@@ -811,14 +812,14 @@ def addPrinter(printer_name, device_uri, location, ppd_file, model, info):
     return cupsext.addPrinter(printer_name, device_uri, location, ppd_file, model, info)
 
 def delPrinter(printer_name):
-    setPasswordPrompt("You do not have permission to delete a printer.")
+    setPasswordPrompt("You do not have permission to delete a printer. You need authentication.")
     return cupsext.delPrinter(printer_name)
 
 def enablePrinter(printer_name):
-    setPasswordPrompt("You do not have permission to enable a printer.")
+    setPasswordPrompt("You do not have permission to enable a printer. You need authentication.")
     cmd_full_path = utils.which('cupsenable', True)
-    cmd= "%s %s"%(cmd_full_path, printer_name)
-    return os.system(cmd)
+    cmd= "%s %s" % (cmd_full_path, printer_name)
+    return os_utils.execute(cmd)
 
 def getGroupList():
     return cupsext.getGroupList()
@@ -852,3 +853,27 @@ def setPasswordPrompt(prompt):
 
 def findPPDAttribute(name, spec):
     return cupsext.findPPDAttribute(name, spec)
+
+def releaseCupsInstance():
+    return cupsext.releaseCupsInstance()
+
+
+def cups_operation(operation_func, mode, ui_toolkit, ui_obj, *cups_op_args):
+    cnt = 0
+    while cnt < 3:
+        cnt += 1
+        result, status_str = operation_func(*cups_op_args)
+        if result != IPP_FORBIDDEN:
+            break
+        else:
+            releaseCupsInstance()
+            if cnt < 3:
+                if mode == INTERACTIVE_MODE:
+                    log.error("Could not connect to CUPS Server due to insufficient privileges.Try with valid user")
+                elif ui_toolkit == 'qt3':
+                    ui_obj.FailureUI("<b>Could not connect to CUPS Server due to insufficient privileges.</b><p>Try with valid user")
+                else:
+                    from ui4 import ui_utils
+                    ui_utils.FailureUI(ui_obj, "<b>Could not connect to CUPS Server due to insufficient privileges.</b><p>Try with valid user")
+
+    return result, status_str
