@@ -59,7 +59,7 @@ BOOL DJ3600::FullBleedCapable (PAPER_SIZE ps, FullbleedType  *fbType, float *xOv
 {
     BYTE    sDevIdStr[DevIDBuffSize];
     char    *pStr;
-    if ((pSS->GetDeviceID (sDevIdStr, DevIDBuffSize, FALSE)) == NO_ERROR)
+    if (pSS->IOMode.bDevID && (pSS->GetDeviceID (sDevIdStr, DevIDBuffSize, FALSE)) == NO_ERROR)
     {
         if ((pStr = strstr ((char *) sDevIdStr, ";S:")))
         {
