@@ -72,7 +72,7 @@ int bug(const char *fmt, ...)
 }
 #endif
 
-void setLogLevel(UXServices *pSS)
+void setLogLevel(UXServices *pSS, char*user_name)
 {
     FILE    *fp;
     char    str[258];
@@ -97,8 +97,8 @@ void setLogLevel(UXServices *pSS)
 
     if (pSS->m_iLogLevel & SAVE_PCL_FILE)
     {
-        char    szFileName[64];
-        snprintf (szFileName,sizeof(szFileName), "/var/log/hp/tmp/hpijs_%d_XXXXXX", getpid());
+        char    szFileName[MAX_FILE_PATH_LEN];
+        snprintf (szFileName,sizeof(szFileName), "%s/hp_%s_ijs_%d_XXXXXX", CUPS_TMP_DIR, user_name,  getpid());
         createTempFile(szFileName, &pSS->outfp);
 
 //	pSS->outfp = fopen (szFileName, "w");
@@ -588,7 +588,8 @@ int main (int argc, char *argv[], char *evenp[])
    char *raster = NULL, *k_raster = NULL;
    int status = EXIT_FAILURE;
    int ret, n, i, kn=0, width, k_width;
-
+   char user_name[32]={0,};
+        
    openlog("hpijs", LOG_PID,  LOG_DAEMON);
 
    if (argc > 1)
@@ -602,6 +603,9 @@ int main (int argc, char *argv[], char *evenp[])
       }
    }
 
+   if (argc > 2)
+        strncpy(user_name, argv[2], sizeof(user_name));
+
 #ifdef HAVE_LIBHPIP
    char *pDev;
    if ((pDev = getenv ("DEVICE_URI")) &&
@@ -625,11 +629,11 @@ int main (int argc, char *argv[], char *evenp[])
       goto BUGOUT;
    }
 
-   setLogLevel(pSS);
+   setLogLevel(pSS, user_name);
 
 #ifdef CAPTURE
-   char szCapOutFile[64];
-   snprintf(szCapOutFile, sizeof(szCapOutFile),"%s/capout_XXXXXX","/var/log/hp/tmp");
+   char szCapOutFile[MAX_FILE_PATH_LEN];
+   snprintf(szCapOutFile, sizeof(szCapOutFile),"%s/hp_%s_ijs_capout_XXXXXX",CUPS_TMP_DIR, user_name);
    if ((pSS->InitScript(szCapOutFile, TRUE)) != NO_ERROR)
       BUG("unable to init capture");
 #endif
