@@ -384,8 +384,13 @@ class LJFastRasterProxy;
 class LJZjsMonoProxy;
 #endif
 
+#ifdef APDK_LJZJS_COLOR
+class LJZjsColorProxy;
+#endif
+
 #ifdef APDK_LJM1005
 class LJM1005Proxy;
+class LJP1XXXProxy;
 #endif
 
 #if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
@@ -456,6 +461,7 @@ class DJ350Proxy;
 #if defined(APDK_DJ3600) && defined (APDK_DJ3320)
 class DJ3600Proxy;
 class DJ4100Proxy;
+class DJD2600Proxy;
 #endif
 
 #if defined (APDK_DJ3320)
@@ -539,8 +545,13 @@ public:
     static LJZjsMonoProxy s_LJZjsMonoProxy;
 #endif
 
+#ifdef APDK_LJZJS_COLOR
+    static LJZjsColorProxy s_LJZjsColorProxy;
+#endif
+
 #ifdef APDK_LJM1005
     static LJM1005Proxy s_LJM1005Proxy;
+    static LJP1XXXProxy s_LJP1XXXProxy;
 #endif
 
 #if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
@@ -611,6 +622,7 @@ public:
 #if defined(APDK_DJ3600) && defined (APDK_DJ3320)
     static DJ3600Proxy s_DJ3600Proxy;
     static DJ4100Proxy s_DJ4100Proxy;
+    static DJD2600Proxy s_DJD2600Proxy;
 #endif
 
 #if defined (APDK_DJ3320)
