@@ -62,6 +62,8 @@ resize = 100
 contrast = 0
 set_contrast = False
 brightness = 0
+set_brightness = False
+brightness = 0
 page_size = ''
 size_desc = ''
 page_units = 'mm'
@@ -69,6 +71,8 @@ default_res = 300
 scanner_compression = 'JPEG'
 adf = False
 duplex = False
+dest_printer = None
+dest_devUri = None
 
 PAGE_SIZES = { # in mm
     '5x7' : (127, 178, "5x7 photo", 'in'),
@@ -136,8 +140,10 @@ try:
         ("Scanning resolution:", "-r<resolution_in_dpi> or --res=<resolution_in_dpi> or --resolution=<resolution_in_dpi>", "option", False),
         ("", "where 300 is default.", "option", False),
         ("Image resize:", "--resize=<scale_in_%> (min=1%, max=400%, default=100%)", "option", False),
-        ("Image contrast:", "--contrast=<contrast> or -c=<contrast>", "option", False),
+        ("Image contrast:", "-c=<contrast> or --contrast=<contrast>", "option", False),
         ("", "The contrast range varies from device to device.", "option", False),
+        ("Image brightness:", "-b=<brightness> or --brightness=<brightness>", "option", False),
+        ("", "The brightness range varies from device to device.", "option", False),
         ("ADF mode:", "--adf (Note, only PDF output is supported when using the ADF)", "option", False),
         ("", "--duplex or --dup for duplex scanning using ADF.", "option", False),
         utils.USAGE_SPACE,
@@ -188,7 +194,8 @@ try:
         ("", 'Use double quotes (") around the note/message if it contains space characters.', "option", False),
         utils.USAGE_SPACE,
         ("[OPTIONS] ('printer' dest)", "", "header", False),
-        ("Printer queue/printer:", "--printer=<printer_name>", "option", False),
+        ("Printer queue/printer dest:", "--dp=<printer_name> or --dest-printer=<printer_name>", "option", False),
+        ("Printer device-URI dest:", "--dd=<device-uri> or --dest-device=<device-uri>", "option", False),
         utils.USAGE_SPACE,
         ("[OPTIONS] (advanced)", "", "header", False),
         ("Set the scanner compression mode:", "-x<mode> or --compression=<mode>, <mode>='raw', 'none' or 'jpeg' ('jpeg' is default) ('raw' and 'none' are equivalent)", "option", False),],
@@ -209,7 +216,8 @@ try:
                           'greyscale', 'email-subject=',
                           'subject=', 'to=', 'from=', 'jpg',
                           'grey-scale', 'gray-scale', 'about=',
-                          'editor='
+                          'editor=', 'dp=', 'dest-printer=', 'dd=',
+                          'dest-device=', 'brightness=', 
                          ])
 
 
@@ -362,7 +370,7 @@ try:
                     log.error("Invalid value for bry. Using defaults.")
                     bry = None
 
-        elif o in ('-b', '--box'): # tlx, tly, w, h
+        elif o == '--box': # tlx, tly, w, h
             a = a.strip().lower()
             try:
                 tlx, tly, width, height = a.split(',')[:4]
@@ -422,8 +430,8 @@ try:
                 if 'file' in dest:
                     dest.remove('file')
             else:
-                if ext.lower() not in ('.jpg', '.png'):
-                    log.error("Only JPG (.jpg) and PNG (.png) output files are supported.")
+                if ext.lower() not in ('.jpg', '.png', '.pdf'):
+                    log.error("Only JPG (.jpg), PNG (.png) and PDF (.pdf) output files are supported.")
                     output = ''
                     if 'file' in dest:
                         dest.remove('file')
@@ -438,11 +446,20 @@ try:
             a = a.strip().lower().split(',')
             for aa in a:
                 aa = aa.strip()
-                if aa in ('file', 'viewer', 'editor', 'printer', 'print', 'email', 'pdf') \
+                if aa in ('file', 'viewer', 'editor', 'print', 'email', 'pdf') \
                     and aa not in dest:
-                    if aa == 'print': aa = 'printer'
                     dest.append(aa)
 
+        elif o in ('--dd', '--dest-device'):
+            dest_devUri = a.strip()
+            if 'print' not in dest:
+                dest.append('print')
+
+        elif o in ('--dp', '--dest-printer'):
+            dest_printer = a.strip()
+            if 'print' not in dest:
+                dest.append('print')
+
         elif o in ('-v', '--viewer'):
             a = a.strip()
             b = utils.which(a)
@@ -503,15 +520,20 @@ try:
                 log.error("Invalid resize value. Using default of 100%.")
 
         elif o in ('-b', '--brightness'):
-            pass
+            try:
+                set_brightness = True
+                brightness = int(a.strip())
+            except ValueError:
+                log.error("Invalid brightness value. Using default of 0.")
+                brightness = 0
 
         elif o in ('-c', '--contrast'):
             try:
                 set_contrast = True
                 contrast = int(a.strip())
             except ValueError:
-                log.error("Invalid contrast value. Using default of 100.")
-                contrast = 100
+                log.error("Invalid contrast value. Using default of 0.")
+                contrast = 0
 
         elif o == '--adf':
             adf = True
@@ -521,12 +543,6 @@ try:
             adf = True
             output_type = 'pdf'
 
-    if printer_name is not None and \
-        device.getDeviceURIByPrinterName(printer_name) is not None and \
-        'printer' not in dest:
-
-        dest.append('printer')
-
     if not dest:
         log.warn("No destinations specified. Adding 'file' destination by default.")
         dest.append('file')
@@ -619,11 +635,14 @@ try:
             sane.reportError(e)
             sys.exit(1)
 
-        source_option = device.getOptionObj("source").constraint
-        log.debug("Supported source Options: %s size=%d" % (source_option,len(source_option)))
-        if source_option is None:
-             log.error("Device doesn't have scanner.")
-             sys.exit(1)
+        try:
+            source_option = device.getOptionObj("source").constraint
+            log.debug("Supported source Options: %s size=%d" % (source_option,len(source_option)))
+            if source_option is None:
+                log.error("Device doesn't have scanner.")
+                sys.exit(1)
+        except:
+            log.error("Failed to get the source from device.")
 
         #check if device has only ADF
         if 'Flatbed' not in source_option and 'ADF' in source_option:
@@ -714,10 +733,20 @@ try:
                     contrast = int(valid_contrast[0])
                 elif contrast > int(valid_contrast[1]):
                     contrast = int(valid_contrast[1])
-
-
             device.setOption('contrast', contrast)
 
+        if set_brightness:
+            valid_brightness = device.getOptionObj('brightness').constraint
+            if brightness >= int(valid_brightness[0]) and brightness <= int(valid_brightness[1]):
+                brightness = device.getOptionObj('brightness').limitAndSet(brightness)
+            else:
+                log.warn("Invalid brightness. Brightness range is (%d, %d). Using closest valid brightness of %d " % (int(valid_brightness[0]), int(valid_brightness[1]), brightness))
+                if brightness < int(valid_brightness[0]):
+                    brightness = int(valid_brightness[0])
+                elif brightness > int(valid_brightness[1]):
+                    brightness = int(valid_brightness[1])
+            device.setOption('brightness', brightness)
+
         if brx - tlx <= 0.0 or bry - tly <= 0.0:
             log.error("Invalid scan area (width or height is negative).")
             sys.exit(1)
@@ -728,6 +757,8 @@ try:
         log.info("Compression: %s" % scanner_compression)
         if(set_contrast):
             log.info("Contrast: %d" % contrast)
+        if(set_brightness):
+            log.info("Brightness: %d" % brightness)
         if units == 'mm':
             log.info("Scan area (mm):")
             log.info("  Top left (x,y): (%fmm, %fmm)" % (tlx, tly))
@@ -874,7 +905,7 @@ try:
                             log.debug("Expecting to read %s from scanner." % utils.format_bytes(expected_bytes))
 
                     device.waitForScanActive()
-
+                    
                     pm = tui.ProgressMeter("Reading data:")
 
                     while device.isScanActive():
@@ -952,11 +983,11 @@ try:
                             log.error("Did not read enough data from scanner (I/O Error?)")
                             sys.exit(1)
 
-                    if adf:
+                    if adf or output_type == 'pdf':
                         temp_output = utils.createSequencedFilename("hpscan_pg%d_" % page, ".png")
                         adf_page_files.append(temp_output)
                         im.save(temp_output)
-                        log.debug("Saved page %d to file %s" % (page, temp_output))
+                        #log.debug("Saved page %d to file %s" % (page, temp_output))
                 else:
                     log.error("No data read.")
                     sys.exit(1)
@@ -970,7 +1001,7 @@ try:
             log.info("Closing device.")
             device.cancelScan()
 
-        if adf:
+        if adf or output_type == 'pdf':
             try:
                 from reportlab.pdfgen import canvas
             except ImportError:
@@ -983,7 +1014,7 @@ try:
             c = canvas.Canvas(output, (brx/0.3528, bry/0.3528))
 
             for p in adf_page_files:
-                log.info("Processing page %s..." % p)
+                #log.info("Processing page %s..." % p)
                 image = Image.open(p)
 
                 try:
@@ -993,6 +1024,7 @@ try:
                     sys.exit(1)
 
                 c.showPage()
+                os.unlink(p)
 
             log.info("Saving to file %s" % output)
             c.save()
@@ -1037,7 +1069,7 @@ try:
             dest.remove("file")
 
         temp_saved = False
-        if ('editor' in dest or 'viewer' in dest or 'email' in dest or 'printer' in dest) \
+        if ('editor' in dest or 'viewer' in dest or 'email' in dest or 'print' in dest) \
             and not file_saved:
 
             output_fd, output = utils.make_temp_file(suffix='.png')
@@ -1083,13 +1115,20 @@ try:
                 os_utils.execute(cmd)
                 sys.exit(0)
 
-            elif d == 'printer':
-                hp_print = utils.which("hp-print")
-                if hp_print:
-                    cmd = 'hp-print %s &' % output
+            elif d == 'print':
+                hp_print = utils.which("hp-print", True)
+                if not hp_print:
+                    hp_print = 'python ./print.py'
+                 
+                if dest_printer is not None:
+                   cmd = '%s -p %s %s &' % (hp_print, dest_printer, output)
+                elif dest_devUri is not None:
+		   tmp = dest_devUri.partition(":")[2]
+		   dest_devUri = "hp:" + tmp
+                   cmd = '%s -d %s %s &' % (hp_print, dest_devUri, output)
                 else:
-                    cmd = "python ./print.py %s &" % output
-
+                   cmd = '%s %s &' % (hp_print, output)
+                
                 os_utils.execute(cmd)
 
             elif d == 'email':
