@@ -22,7 +22,7 @@
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
   
-  Author: David Suffield, Yashwant Sahu  
+  Author: David Suffield, Yashwant Sahu, Sarbeswar Meher  
 
 \************************************************************************************/
 
@@ -32,6 +32,9 @@
 #define MARVELL_CONTRAST_MIN 1
 #define MARVELL_CONTRAST_MAX 11
 #define MARVELL_CONTRAST_DEFAULT 6
+#define MARVELL_BRIGHTNESS_MIN 0
+#define MARVELL_BRIGHTNESS_MAX 200
+#define MARVELL_BRIGHTNESS_DEFAULT 6
 
 #define MM_PER_INCH     25.4
 
@@ -44,6 +47,7 @@ enum MARVELL_OPTION_NUMBER
                    MARVELL_OPTION_INPUT_SOURCE,     /* platen, ADF */ 
    MARVELL_OPTION_GROUP_ADVANCED,
                    MARVELL_OPTION_CONTRAST,
+                   MARVELL_OPTION_BRIGHTNESS,
    MARVELL_OPTION_GROUP_GEOMETRY,
                    MARVELL_OPTION_TL_X,
                    MARVELL_OPTION_TL_Y,
@@ -102,6 +106,8 @@ struct marvell_session
 
    SANE_Range contrast_range;
    SANE_Int current_contrast;
+   SANE_Range brightnessRange;
+   SANE_Int currentBrightness;
 
    SANE_Range tlxRange, tlyRange, brxRange, bryRange;
    SANE_Fixed currentTlx, currentTly, currentBrx, currentBry;
