@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 #
-# (c) Copyright 2001-2004 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2008 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,11 +19,23 @@
 # Author: Don Welch
 #
 
+# Std Lib
 import sys
+import os.path
+
+# Qt
 from qt import *
+
+# Local
+from base.g import *
 from aboutdlg_base import AboutDlg_base
+from ui_utils import load_pixmap
+
 
 class AboutDlg(AboutDlg_base):
     def __init__(self,parent = None,name = None,modal = 0,fl = 0):
         AboutDlg_base.__init__(self,parent,name,modal,fl)
 
+        self.pyPixmap.setPixmap(load_pixmap('powered_by_python.png'))
+        self.osiPixmap.setPixmap(load_pixmap('opensource-75x65.png'))
+        self.logoPixmap.setPixmap(load_pixmap('hp-tux-printer.png'))
