@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2001-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2008 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,9 +19,14 @@
 # Author: Don Welch
 #
 
+# Std Lib
+
+# Local
 from base.g import *
 from base import maint
-import os.path
+from ui_utils import load_pixmap
+
+# Qt
 from qt import *
 from align10form_base import Align10Form_Base
 
@@ -29,9 +34,9 @@ from align10form_base import Align10Form_Base
 class Align10Form(Align10Form_Base):
     def __init__(self, pattern, align_type=ALIGN_TYPE_LBOW, parent = None, name = None, modal = 0, fl = 0):
         Align10Form_Base.__init__(self,parent,name,modal,fl)
-        self.Icon.setPixmap(QPixmap(os.path.join(prop.image_dir, 'align10.png')))
+        self.Icon.setPixmap(load_pixmap('align10'))
 
-        self.controls = maint.align10and11Controls(pattern, align_type)
+        self.controls = maint.align10and11and14Controls(pattern, align_type)
 
         for line in self.controls:
             if not self.controls[line][0]:
@@ -42,11 +47,14 @@ class Align10Form(Align10Form_Base):
 
     def getValues(self):
         ret = []
-        for line in self.controls:
+        controls = self.controls.keys()
+        controls.sort()
+        
+        for line in controls:
             if not self.controls[line][0]:
                 ret.append(0)
             else:
-                exec('selected = str(self.comboBox%s.currentText())' % line)
+                exec('selected = unicode(self.comboBox%s.currentText())' % line)
                 try:
                     selected = int(selected[1:])
                 except ValueError:
