@@ -51,6 +51,7 @@ BUTTON_CLEAN = 0
 BUTTON_NEXT = 1
 BUTTON_FINISH = 2
 
+LEDM_CLEAN_VERIFY_PAGE_JOB="<ipdyn:JobType>cleaningVerificationPage</ipdyn:JobType>"
 
 #d = None
 def true():
@@ -74,6 +75,7 @@ class CleanDialog(QDialog, Ui_Dialog):
                       CLEAN_TYPE_PCL : 4,
                       CLEAN_TYPE_LIDIL : 4,
                       CLEAN_TYPE_PCL_WITH_PRINTOUT : 4,
+                      CLEAN_TYPE_LEDM : 4,
                     }
 
         self.seq = { # (func|method, tuple of params|None)
@@ -127,6 +129,20 @@ class CleanDialog(QDialog, Ui_Dialog):
                             # TODO: Add print-out
                             (self.close, None),
                             ],
+
+                    CLEAN_TYPE_LEDM : [ # 4
+                            (self.showLevel1Page, None),
+                            (self.endLevel1Page, None),
+                            (self.doClean, (1,)),
+                            (self.showLevel2Page, None),
+                            (self.endLevel2Page, None),
+                            (self.doClean, (2,)),
+                            (self.showLevel3Page, None),
+                            (self.endLevel3Page, None),
+                            (self.doClean, (3,)),
+                            # TODO: Add print-out
+                            (self.close, None),
+                            ],
                     }
 
 
@@ -283,25 +299,51 @@ class CleanDialog(QDialog, Ui_Dialog):
 
                         if level == 1:
                             maint.cleanType1(self.dev)
+                            maint.print_clean_test_page(self.dev)
 
                         elif level == 2:
                             maint.primeType1(self.dev)
+                            maint.print_clean_test_page(self.dev)
 
                         else: # 3
                             maint.wipeAndSpitType1(self.dev)
+                            maint.print_clean_test_page(self.dev)
 
 
                     elif self.clean_type == CLEAN_TYPE_LIDIL: # 2
                         if level == 1:
                             maint.cleanType2(self.dev)
+                            maint.print_clean_test_page(self.dev)
 
                         elif level == 2:
                             maint.primeType2(self.dev)
+                            maint.print_clean_test_page(self.dev)
 
                         else: # 3
                             maint.wipeAndSpitType2(self.dev)
+                            maint.print_clean_test_page(self.dev)
 
-                    maint.print_clean_test_page(self.dev)
+                    elif self.clean_type == CLEAN_TYPE_LEDM: # 4
+                        IPCap_data = maint.getCleanLedmCapacity(self.dev)
+                        print_verification_page = True
+                        if LEDM_CLEAN_VERIFY_PAGE_JOB not in IPCap_data:
+                            print_verification_page = False
+
+                        if level == 1:
+                            maint.cleanTypeLedm(self.dev)
+                            maint.cleanTypeVerify(self.dev,level, print_verification_page)
+                            if print_verification_page is False:
+                                self.setCustomMessage(self.Prompt_5,"Cleaning level 1 is Completed. \nPress \"Cancel\" to Finish. Press \"Clean\" for next level clean")
+
+                        elif level == 2:
+                            maint.cleanTypeLedm1(self.dev)
+                            maint.cleanTypeVerify(self.dev,level, print_verification_page)
+                            if print_verification_page is False:
+                                self.setCustomMessage(self.Prompt_6,"Cleaning level 2 is Completed. \nPress \"Cancel\" to Finish. Press \"Clean\" for next level clean")
+
+                        else: # 3
+                            maint.cleanTypeLedm2(self.dev)
+                            maint.cleanTypeVerify(self.dev,level, print_verification_page)
 
                 else:
                     CheckDeviceUI(self)
@@ -343,6 +385,9 @@ class CleanDialog(QDialog, Ui_Dialog):
             self.NextButton.setText(self.__tr("Finish"))
 
 
+    def setCustomMessage(self, button, message):
+        button.setText(self.__tr(message))
+
     def __tr(self,s,c = None):
         return qApp.translate("CleanDialog",s,c)
 
